@@ -1,25 +1,28 @@
-% Copyright (C) 2024  Eric Ludlam (and others)
-
+% Copyright (C) 2019-2025 Free Software Foundation, Inc.
+%
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
 % the Free Software Foundation, either version 3 of the License, or
 % (at your option) any later version.
-
+%
 % This program is distributed in the hope that it will be useful,
 % but WITHOUT ANY WARRANTY; without even the implied warranty of
 % MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 % GNU General Public License for more details.
-
+%
 % You should have received a copy of the GNU General Public License
 % along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 function ebclear(varargin)
-% Emacs version of dbstop.  Tells emacs which breakpoints are active.
-    
-    dbclear(varargin{:});
-    
+% Emacs version of dbclear.
+% Removes a breakpoint and tells Emacs about that.
+
+    args = emacsstripremote(varargin);
+
+    dbclear(args{:});
+
     % Send emacs some breakpoints
     bp = getappdata(groot, 'EmacsBreakpoints');
     bp.updateEmacs;
 
 end
-
